@@ -28,7 +28,11 @@
 #define GCHEMPAINT_MENDELEIEV_H
 
 #include "dialog.h"
-#include <gtkperiodic/gtkperiodic.h>
+#ifdef GCU_OLD_VER
+#	include <gtkperiodic/gtkperiodic.h>
+#else
+#	include <gcu/gtkperiodic.h>
+#endif
 
 class gcpMendeleievDlg: public gcpDialog
 {
